2 ms·
It's slower than native python. %timeit round(12335423552.33, -6) %timeit int(12335423552.33 / 1_000_000.0) * 1_000_000.0 500 ns ± 3.88 ns per loop
by ben509 7y ago
It's slower than native python.
%timeit round(12335423552.33, -6)
%timeit int(12335423552.33 / 1_000_000.0) * 1_000_000.0
500 ns ± 3.88 ns per loop (mean ± std. dev. of 7 runs, 1000000 loops each)
219 ns ± 1.1 ns per loop (mean ± std. dev. of 7 runs, 1000000 loops each)
- dagw 7y agoWell obviously the approach round() takes is slower than the naive approach. The whole point of doing it the way round() does it is that it gives the correct answer in cases where the naive approach fails.